@@ -1,9 +1,9 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "robe" "0.8.6"
+(define-package "robe" "20250219.1910"
   "Code navigation, documentation lookup and completion for Ruby."
   '((inf-ruby "2.5.1")
-    (emacs    "25.1"))
+    (emacs    "27.1"))
   :url "https://github.com/dgutov/robe"
-  :commit "43a85c2eb6e52f4e684919210dd84d67289938c1"
-  :revdesc "43a85c2eb6e5"
+  :commit "73a78e55394c1c70c11f9354ef52e7ffce31547c"
+  :revdesc "73a78e55394c"
   :keywords '("ruby" "convenience" "rails"))
