@@ -5,10 +5,10 @@
 
 ;; Author: Dmitry Gutov
 ;; URL: https://github.com/dgutov/robe
-;; Package-Version: 0.8.6
-;; Package-Revision: 43a85c2eb6e5
+;; Package-Version: 20250219.1910
+;; Package-Revision: 73a78e55394c
 ;; Keywords: ruby convenience rails
-;; Package-Requires: ((inf-ruby "2.5.1") (emacs "25.1"))
+;; Package-Requires: ((inf-ruby "2.5.1") (emacs "27.1"))
 
 ;; This file is NOT part of GNU Emacs.
 
@@ -116,7 +116,7 @@ When nil, the source can be shown by pressing the button.
 When auto, the source will be shown when there is no doc."
   :type '(choice (const :tag "Hidden by default" nil)
                  (const :tag "Shown by default" t)
-                 (const :tag "When there is not doc" auto)))
+                 (const :tag "When there is no doc" auto)))
 
 (defun robe-completing-read (&rest args)
   (let ((completing-read-function
@@ -138,6 +138,7 @@ When called with a prefix argument, kills the current Ruby
 process, if any, and starts a new console for the current
 project."
   (interactive "P")
+  (defvar inf-ruby-interact-with-fromcomp)
   (let* ((ruby-buffer (robe-inf-buffer))
          (process (get-buffer-process ruby-buffer)))
     (when (or force (not process))
@@ -155,7 +156,8 @@ project."
             (set-window-configuration conf))
         (error "Aborted"))))
   (when (not (robe-running-p))
-    (let* ((proc (inf-ruby-proc))
+    (let* ((inf-ruby-interact-with-fromcomp nil)
+           (proc (inf-ruby-proc))
            started failed
            (comint-filter (process-filter proc))
            (tmp-filter (lambda (p s)
@@ -566,26 +568,35 @@ If invoked with a prefix or no symbol at point, delegate to `robe-ask'."
    (lambda (file)
      (with-temp-buffer
        (insert-file-contents file)
-       (ruby-mode)
-       (condition-case nil
-           (let* ((_ (robe--scan-to-const resolved-name))
-                  (found-name (or (match-string 2) (match-string 1)))
-                  new-module
-                  (full-name (if (match-beginning 1)
-                                 ;; Working around a bug in
-                                 ;; ruby-add-log-current-method
-                                 ;; where it can look at the preceding
-                                 ;; module when at bol.
-                                 (car (robe-context))
-                               (goto-char (match-beginning 2))
-                               (setq new-module (car (robe-context)))
-                               (if new-module
-                                   (concat new-module "::" found-name)
-                                 found-name))))
-             (equal full-name resolved-name))
-         (search-failed nil))))
+       (robe--const-here-p resolved-name)))
    files))
 
+(defun robe--const-here-p (resolved-name)
+  ;; Using ruby-ts-mode would be cleaner, but it's Emacs 29+.
+  (ruby-mode)
+  (condition-case nil
+      (let* ((_ (robe--scan-to-const resolved-name))
+             (found-name (or (match-string 2) (match-string 1)))
+             new-module
+             (full-name (if (match-beginning 1)
+                            ;; Working around a bug in
+                            ;; ruby-add-log-current-method
+                            ;; where it can look at the preceding
+                            ;; module when at bol.
+                            (save-excursion
+                              (unless (re-search-forward "\\_<end\\_>"
+                                                         (line-end-position)
+                                                         t)
+                                (forward-line))
+                              (car (robe-context)))
+                          (goto-char (match-beginning 2))
+                          (setq new-module (car (robe-context)))
+                          (if new-module
+                              (concat new-module "::" found-name)
+                            found-name))))
+        (equal full-name resolved-name))
+    (search-failed nil)))
+
 (defun robe-context ()
   (let* ((ruby-symbol-re "[a-zA-Z0-9_?!]")
          (current-method (and add-log-current-defun-function
@@ -757,6 +768,8 @@ Only works with Rails, see e.g. `rinari-console'."
         (font-lock-syntax-table nil)
         (syntax-propertize-function #'ruby-syntax-propertize-function)
         (font-lock-defaults '((ruby-font-lock-keywords) nil nil ((?_ . "w")
+                                                                 (?' . "\"")
+                                                                 (?/ . "\"")
                                                                  (?# . "<")
                                                                  (?\n . ">"))))
         (font-lock-dont-widen t))
@@ -1167,9 +1180,10 @@ Only works with Rails, see e.g. `rinari-console'."
                          (* (in " \t"))
                          "def"
                          (* (in " \t"))
-                         (optional (+ (in "a-z" "A-Z" ?:)) ?.))
-                        (and method-name (regexp-quote method-name))
-                        (rx symbol-end)))
+                         (optional (+ (in "a-z" "A-Z" ?:)) ?.)
+                         (literal (or method-name ""))
+                         ;; Workaround for major modes which don't s-p ?! methods.
+                         (or " " "#" "(" line-end point))))
         (block-regexp (rx
                        (or
                         (syntax ?w) (syntax ?_) (syntax ?\)) (syntax ?\") (syntax ?|))
@@ -1209,9 +1223,13 @@ Only works with Rails, see e.g. `rinari-console'."
         vars)
     (save-excursion
       (when (and method-name
-                 (re-search-backward method-regexp nil)
-                 (progn
-                   (goto-char (match-end 0))
+                 ;; Can be [legitimately] nil with ruby-ts-mode.
+                 (re-search-backward method-regexp nil t)
+                 (goto-char (match-end 0))
+                 (if (eq ?\( (char-before))
+                     (progn
+                      (forward-char -1)
+                      t)
                    (skip-chars-forward " \t")
                    (eq ?\( (char-after))))
         (let* ((beg (1+ (point)))
